@@ -520,14 +520,15 @@ def get_phones(type, prefix='+33'):
     """
     assert type
     if type not in ('phone', 'mobile', 'all', 'dict'):
-        raise Exception('`type` is incorrect. Valid values are `phone`, `mobile`, `all`')
+        raise Exception('`type` is incorrect. Valid values are `phone`, `mobile`, `all` and `dict`')
 
     def _get_phones(self, model, field, value, line):
-        res = {'phone': [], 'mobile': [], 'all': [], 'value': value}
+        res = {'phone': [], 'mobile': [], 'all': []}
 
         # On ne garde que les caractères numériques
         string = re.sub(u'[^0-9]', u'', value)
         stop = False
+        result = ''
         i = 0
         while not stop:
             i += 1
@@ -577,7 +578,7 @@ def get_phones(type, prefix='+33'):
             result = ' / '.join(phones)
         elif len(phones) == 1:
             result = phones[0]
-         
+        
         return result
 
     return _get_phones
