@@ -29,27 +29,37 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
 ##############################################################################
+
 """
-Unicode CSV reader and writer rewriting.
+Unicode CSV reader and writer module.
 
 """
 
+from copy import deepcopy
 import csv
 
-def _is_null(string):
-    return str(string) in ('False', '0', 'NULL', 'null') and '' or string
+def _is_null(elmt):
+    if elmt in ('Null',  'NULL', 'null'):
+        return ''
+    else:
+        return elmt
 
 class Reader:
     """Return an unicode CSV reader
 
     """
     def __init__(self, f, dialect=csv.excel, encoding="utf-8", **kwds):
-        self.reader = csv.reader(f, dialect=dialect, **kwds)
+        self.reader = deepcopy(list(csv.reader(f, dialect=dialect, **kwds)))
+        f.close()
+        self.offset = 0
         self.encoding = encoding
 
     def next(self):
-        row = self.reader.next()
-        return [unicode(_is_null(s), self.encoding) for s in row]
+        if self.offset >= len(self.reader):
+            raise StopIteration
+        row = self.reader[self.offset]
+        self.offset += 1
+        return [unicode(_is_null(elmt), self.encoding) for elmt in row]
 
     def __iter__(self):
         return self
@@ -63,9 +73,10 @@ class Writer:
         self.encoding = encoding
 
     def writerow(self, row):
-        self.writer.writerow([_is_null(s).encode("utf-8") for s in row])
+        self.writer.writerow([_is_null(elmt).encode("utf-8") for elmt in row])
 
     def writerows(self, rows):
         for row in rows:
             self.writerow(row)
 
+
